@@ -30,59 +30,60 @@
 static LV2_Descriptor *gateDescriptor = NULL;
 
 class Gate {
-	public:
-		Gate() {
-			state = CLOSED;
-			gate = 0;
-			holding = 0;
-		}
-		~Gate() {}
+public:
+	Gate() {
+		state = CLOSED;
+		gate = 0;
+		holding = 0;
+	}
+	~Gate() {
+	}
 
-		float *switch_button, *threshold, *attack, *hold, *decay, *range, sample_rate, gate, *output;
-		const float *input;
-		int state, holding;
+	float *switch_button, *threshold, *attack, *hold, *decay, *range, sample_rate, gate, *output;
+	const float *input;
+	int state, holding;
 };
 
-static LV2_Handle instantiateGate(const _LV2_Descriptor *descriptor, double s_rate, const char *path, const LV2_Feature * const* features) {
+static LV2_Handle instantiateGate(const _LV2_Descriptor *descriptor, double s_rate, const char *path, const LV2_Feature * const * features) {
 	Gate *plugin_data = new Gate;
 	plugin_data->sample_rate = s_rate;
-	return (LV2_Handle)plugin_data;
+	return (LV2_Handle) plugin_data;
 }
 
 static void connectPortGate(LV2_Handle instance, uint32_t port, void *data) {
-	Gate *plugin = (Gate *)instance;
+	Gate *plugin = (Gate *) instance;
 
 	switch (port) {
-		case p_switch:
-			plugin->switch_button = (float*)data;
-			break;
-		case p_threshold:
-			plugin->threshold = (float*)data;
-			break;
-		case p_attack:
-			plugin->attack = (float*)data;
-			break;
-		case p_hold:
-			plugin->hold = (float*)data;
-			break;
-		case p_decay:
-			plugin->decay = (float*)data;
-			break;
-		case p_gaterange:
-			plugin->range = (float*)data;
-			break;
-		case p_input:
-			plugin->input = (const float*)data;
-			break;
-		case p_output:
-			plugin->output = (float*)data;
-			break;
+	case p_switch:
+		plugin->switch_button = (float*) data;
+		break;
+	case p_threshold:
+		plugin->threshold = (float*) data;
+		break;
+	case p_attack:
+		plugin->attack = (float*) data;
+		break;
+	case p_hold:
+		plugin->hold = (float*) data;
+		break;
+	case p_decay:
+		plugin->decay = (float*) data;
+		break;
+	case p_gaterange:
+		plugin->range = (float*) data;
+		break;
+	case p_input:
+		plugin->input = (const float*) data;
+		break;
+	case p_output:
+		plugin->output = (float*) data;
+		break;
 	}
 }
 
 static void runGate(LV2_Handle instance, uint32_t sample_count) {
 
-	Gate *plugin_data = (Gate *)instance;
+	Gate *plugin_data = (Gate *) instance;
 
 	float * const output = plugin_data->output;
 	const float * const input = plugin_data->input;
@@ -109,7 +110,7 @@ static void runGate(LV2_Handle instance, uint32_t sample_count) {
 		const int hold_samples = round(hold * sample_rate * 0.001);
 		const float decay_coef = 1000 / (decay * sample_rate);
 		const float range_coef = range > -90 ? pow(10, range * 0.05) : 0;
-		
+
 		int state = plugin_data->state;
 		float gate = plugin_data->gate;
 		int holding = plugin_data->holding;
@@ -120,71 +121,78 @@ static void runGate(LV2_Handle instance, uint32_t sample_count) {
 			float sample = input[i];
 			float abs_sample = fabs(sample);
 
-			switch (state){
-				case CLOSED:
-				case DECAY:
-					if (abs_sample >= threshold_value) { state = ATTACK; }
-					break;
-				case ATTACK:
-					break;
-			  	case OPENED:
-			  		if (abs_sample >= threshold_value) { holding = hold_samples; }
-			  		else if (holding <= 0) { state = DECAY; }
-					else { holding--; }
-					break;
-				default:
-					// shouldn't happen
-					state = CLOSED;
+			switch (state) {
+			case CLOSED:
+			case DECAY:
+				if (abs_sample >= threshold_value) {
+					state = ATTACK;
+				}
+				break;
+			case ATTACK:
+				break;
+			case OPENED:
+				if (abs_sample >= threshold_value) {
+					holding = hold_samples;
+				} else if (holding <= 0) {
+					state = DECAY;
+				} else {
+					holding--;
+				}
+				break;
+			default:
+				// shouldn't happen
+				state = CLOSED;
 			}
 
 			// handle attack/decay in a second pass to avoid unnecessary one-sample delay
-			switch (state){
-				case CLOSED:
-					output[i] = sample * range_coef;
-					break;
-				case DECAY:
-					gate -= decay_coef;
-					if (gate <= 0) {
-						gate = 0;
-						state = CLOSED;
-					}
-					output[i] = sample * (range_coef * (1 - gate) + gate);
-			    		break;
-				case ATTACK:
-			 		gate += attack_coef;
-					if (gate >= 1) {
-						gate = 1;
-						state = OPENED;
-						holding = hold_samples;
-					}
-					output[i] = sample * (range_coef * (1 - gate) + gate);
-			    		break;
-			    	case OPENED:
-			    		output[i] = sample;
-			    		break;
+			switch (state) {
+			case CLOSED:
+				output[i] = sample * range_coef;
+				break;
+			case DECAY:
+				gate -= decay_coef;
+				if (gate <= 0) {
+					gate = 0;
+					state = CLOSED;
+				}
+				output[i] = sample * (range_coef * (1 - gate) + gate);
+				break;
+			case ATTACK:
+				gate += attack_coef;
+				if (gate >= 1) {
+					gate = 1;
+					state = OPENED;
+					holding = hold_samples;
+				}
+				output[i] = sample * (range_coef * (1 - gate) + gate);
+				break;
+			case OPENED:
+				output[i] = sample;
+				break;
 			}
 		}
 
-      		plugin_data->gate = gate;
-      		plugin_data->state = state;
-      		plugin_data->holding = holding;	
-	}
-	else {
+		plugin_data->gate = gate;
+		plugin_data->state = state;
+		plugin_data->holding = holding;
+	} else {
 		// Bypassing
 		if (output != input) {
-			for (uint32_t i = 0; i < sample_count; ++i) { output[i] = input[i]; }
+			for (uint32_t i = 0; i < sample_count; ++i) {
+				output[i] = input[i];
+			}
 		}
 	}
 }
 
 static void cleanupGate(LV2_Handle instance) {
-	Gate *plugin_data = (Gate *)instance;
+	Gate *plugin_data = (Gate *) instance;
 	delete plugin_data;
 }
 
 static void init() {
 
-	gateDescriptor = (LV2_Descriptor *)malloc(sizeof(LV2_Descriptor));
+	gateDescriptor = (LV2_Descriptor *) malloc(sizeof(LV2_Descriptor));
 	gateDescriptor->URI = p_uri;
 	gateDescriptor->instantiate = instantiateGate;
 	gateDescriptor->connect_port = connectPortGate;
@@ -198,12 +206,14 @@ static void init() {
 LV2_SYMBOL_EXPORT
 const LV2_Descriptor *lv2_descriptor(uint32_t index) {
 
-	if (!gateDescriptor) { init(); }
+	if (!gateDescriptor) {
+		init();
+	}
 
 	switch (index) {
-		case 0:
-			return gateDescriptor;
-		default:
-			return NULL;
+	case 0:
+		return gateDescriptor;
+	default:
+		return NULL;
 	}
 }
